import Image from "next/image";

import { ContentLines } from "@/components/shared/content-lines";
import { Button } from "@/components/ui/button";
import { Locale } from "@/i18n/routing";
import { cn } from "@/lib/utils";
import { getAdsData } from "@/utils/get-fake-data";

export default async function Ads({ locale }: { locale: Locale }) {
	const data = await getAdsData();
	const isRTL = locale === "ar";

	return (
		<section className="overflow-hidden bg-custom-background-third">
			<div className="relative min-h-[400px] sm:min-h-[500px] lg:min-h-[600px]">
				{/* Background Image */}
				<Image
					src={data.images.background}
					alt="Pool simulation"
					fill
					className="object-cover"
					priority
				/>

				{/* Main Content Container */}
				<div className="relative mx-auto flex h-full min-h-[400px] w-full max-w-[1380px] items-center sm:min-h-[500px] lg:min-h-[600px]">
					{/* Content Grid */}
					<div className="relative grid w-full grid-cols-1 gap-6 px-4 md:grid-cols-12 md:gap-8 md:px-8 lg:px-12">
						{/* Discount Badge */}
						<div
							className={cn(
								"flex items-center justify-center py-4 md:col-span-5 md:p-8",
								isRTL ? "md:order-last" : "md:order-first"
							)}
						>
							<div className="relative h-32 w-32 sm:h-36 sm:w-36 md:h-40 md:w-40 lg:h-44 lg:w-44">
								<Image
									fill
									src={data.images.offerBadge}
									alt="offer-background"
									className="drop-shadow-lg"
								/>
								<div className="absolute inset-0 flex flex-col items-center justify-center text-white">
									<div className="text-lg font-medium sm:text-xl">
										{data.badge.text?.[locale]}
									</div>
									<span className="text-4xl font-bold sm:text-5xl">
										{data.badge.discount}
									</span>
								</div>
							</div>
						</div>

						{/* Text Content */}
						<div
							className={cn(
								"md:col-span-7",
								isRTL ? "items-end text-right" : "items-start text-left"
							)}
						>
							<div className="relative z-10 w-full max-w-2xl rounded-lg bg-[#1E1E1E96] px-[42px] py-[18px]">
								<ContentLines
									padding="none"
									title={data.content.subtitle?.[locale]}
								/>
								<h3 className="mb-8 mt-14 text-2xl font-normal leading-[48px] text-custom-background-light sm:mb-6 sm:text-3xl md:text-4xl">
									{data.content.title?.[locale]}
								</h3>
								<p className="mb-[52px] text-justify text-base font-normal leading-relaxed text-white">
									{data.content.description?.[locale]}
								</p>
								<div
									className={cn(
										"flex w-full flex-col gap-4 sm:flex-row",
										isRTL ? "sm:flex-row" : "sm:flex-row-reverse"
									)}
								>
									<Button className="relative z-10 w-full bg-blue-500 px-4 py-4 text-sm font-medium hover:bg-blue-600 sm:w-auto sm:px-6 sm:py-5 md:px-8 md:py-6 md:text-base">
										{data.buttons.tryNow[locale]}
									</Button>
									<Button
										variant="outline"
										className="relative z-10 w-full border-[1px] border-white bg-white/10 px-4 py-4 text-sm font-medium text-white hover:bg-white/20 sm:w-auto sm:px-6 sm:py-5 md:px-8 md:py-6 md:text-base"
									>
										{data.buttons.details[locale]}
									</Button>
								</div>
							</div>
						</div>
					</div>
				</div>
			</div>
		</section>
	);
}
